@@ -1,6 +1,7 @@
 import numpy as np
 import scipy.stats as st
 import motus.entropia_divergencia.entropia_aprox_agil as m_eaa
+import motus.entropia_divergencia.entropia_aprox_agil_generalizada as m_eaag
 
 
 def agrega_categoria_entropia(diccionario_entropia, categoria, datos):
@@ -19,7 +20,8 @@ def agrega_categoria_entropia_aproximada(diccionario_entropia,
                                          categoria,
                                          datos,
                                          tamanio_vectorial,
-                                         umbral):
+                                         umbral,
+                                         sobreposicion):
     print("Agrego categoria de entropia aproximada: ")
     print("--------------------------------------------------------------")
     print("Diccionario:", diccionario_entropia)
@@ -28,7 +30,11 @@ def agrega_categoria_entropia_aproximada(diccionario_entropia,
     nuevos_datos = np.array(datos)
     if categoria not in diccionario_entropia:
         print("Procesando informacion")
-        diccionario_entropia[categoria] = m_eaa.calcula_entropia_aprox_agil(nuevos_datos, umbral)
+        diccionario_entropia[categoria] = \
+            m_eaag.calcula_entropia_aprox_agil_general(datos=nuevos_datos,
+                                                       tamanio_vector=tamanio_vectorial,
+                                                       umbral=umbral,
+                                                       sobreposicion=sobreposicion)
     print("Nuevo diccionario: ", diccionario_entropia)
 
 
