@@ -7,6 +7,7 @@ import sys
 from matplotlib.figure import Figure
 import matplotlib.colors as colors
 import matplotlib.pyplot as plt
+from mpl_toolkits.mplot3d import Axes3D
 import pathlib
 import warnings
 from decimal import Decimal
@@ -100,7 +101,7 @@ class Experimento:
                 self.archivo_consecuencias = True
                 arreglo_consecuencias = pd.to_numeric(self.datos['Consecuences'].tail(longitud_datos))
         except:
-            raise Exception('Alguno de los nombres de las columnas del CSV no es correcto. Esto podría ser por un'
+            raise Exception('Alguno de los nombres de las columnas del CSV no es correcto. Esto podria ser por un'
                             ' espacio en blanco al principio del nombre.')
 
         print("--------------------------------------")
@@ -176,12 +177,12 @@ class Experimento:
             if self.verifica_intervalo_tiempo() is False:
                 raise Warning("Los intervalos entre frames del archivo son irregulares. Si desea continuar con el "
                               "procesamiento del archivo, active la casilla  \"Procesamiento tiempo irregular\". "
-                              "Tenga presente que el procesamiento de datos estará basado en el valor medio del "
-                              "total de frames. Le sugerimos explicitar que el procesamiento de datos se realizó "
+                              "Tenga presente que el procesamiento de datos estara basado en el valor medio del "
+                              "total de frames. Le sugerimos explicitar que el procesamiento de datos se realizo "
                               "ajustando el valor de los intervalos entre frames a un valor medio, con base en el "
-                              "siguiente cálculo: Intervalo = (Tiempo final - tiempo inicial)/total de registros")
+                              "siguiente calculo: Intervalo = (Tiempo final - tiempo inicial)/total de registros")
         else:
-            print("Se empieza la generación de tiempos regulares: ")
+            print("Se empieza la generacion de tiempos regulares: ")
             self.genera_tiempos_regulares()
 
         self.distancia_total_recorrida = 0
@@ -221,13 +222,13 @@ class Experimento:
         self.cantidad_posiciones_volumen_4 = None
         self.radios_volumenes = None
 
-        print("Construcción de series de tiempo y de posición.")
+        print("Construccion de series de tiempo y de posicion.")
 
         if self.posiciones_x.max() > dimension_caja[0]:
-            raise Exception('Hay un dato en el eje X que es mayor que la dimensión de la caja. Valor: ',
+            raise Exception('Hay un dato en el eje X que es mayor que la dimension de la caja. Valor: ',
                             self.posiciones_x.max())
         if self.posiciones_y.max() > dimension_caja[1]:
-            raise Exception('Hay un dato en el eje Y que es mayor que la dimensión de la caja. Valor: ',
+            raise Exception('Hay un dato en el eje Y que es mayor que la dimension de la caja. Valor: ',
                             self.posiciones_y.max())
 
     def regresa_tipo_arreglo(self, nombre_arreglo):
@@ -264,7 +265,7 @@ class Experimento:
 
     def calcula_distancias(self):
 
-        print("Cálculo de distancias...")
+        print("Calculo de distancias...")
 
         self.dist_objeto_1, self.dist_objeto_2, self.dist_objeto_3, self.dist_objeto_4 = \
             m_dist.calcula_distancias_a_objetos(self.posiciones_x, self.posiciones_y, self.lista_objetos_relevantes)
@@ -327,21 +328,27 @@ class Experimento:
                                            categoria="aceleracion",
                                            serie=self.serie_aceleracion)
 
-    def calcula_entropias(self, tamanio_vectores, umbral):
+    def calcula_entropias_histogramas_vel_acel(self):
 
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="histograma_velocidad",
                                        datos=self.histogramas["velocidad"])
 
+        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
+                                       categoria="histograma_aceleracion",
+                                       datos=self.histogramas["aceleracion"])
+
+    def calcula_entropias_aproximadas_vel_acel(self,
+                                               tamanio_vectores,
+                                               umbral,
+                                               sobreposicion):
+
         m_ed.agrega_categoria_entropia_aproximada(diccionario_entropia=self.entropias,
                                                   categoria="aproximada_velocidad",
                                                   datos=self.serie_velocidad.to_numpy(),
                                                   tamanio_vectorial=tamanio_vectores,
-                                                  umbral=umbral)
-
-        m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
-                                       categoria="histograma_aceleracion",
-                                       datos=self.histogramas["aceleracion"])
+                                                  umbral=umbral,
+                                                  sobreposicion=sobreposicion)
 
         m_ed.agrega_categoria_entropia_aproximada(diccionario_entropia=self.entropias,
                                                   categoria="aproximada_aceleracion",
@@ -390,7 +397,10 @@ class Experimento:
                                        categoria="histograma_aceleracion_promediada_" + str(cantidad_datos_promedio),
                                        datos=self.histogramas["aceleracion_promediada_" + str(cantidad_datos_promedio)])
 
-    def calcula_regiones_cuadriculadas(self):
+    def calcula_regiones_cuadriculadas(self,
+                                       tamanio_vectorial,
+                                       umbral,
+                                       sobreposicion):
 
         self.arreglo_region_cuadriculada, self.matriz_cuadriculada = \
             m_reg_cuad.calcula_regiones_cuadriculadas(tiempos=self.tiempo,
@@ -400,12 +410,20 @@ class Experimento:
                                                       cantidad_columnas=self.cantidad_columnas,
                                                       dimension_caja=self.dimension_caja)
 
+        m_ed.agrega_categoria_entropia_aproximada(diccionario_entropia=self.entropias,
+                                                  categoria="visitas_regiones_aprox",
+                                                  datos=self.matriz_cuadriculada.flatten(),
+                                                  tamanio_vectorial=tamanio_vectorial,
+                                                  umbral=umbral,
+                                                  sobreposicion=sobreposicion)
+
+        print(self.matriz_cuadriculada)
+
+    def calcula_entropias_regiones_cuadriculadas(self):
         m_ed.agrega_categoria_entropia(diccionario_entropia=self.entropias,
                                        categoria="visitas_regiones",
                                        datos=self.matriz_cuadriculada.flatten())
 
-        print(self.matriz_cuadriculada)
-
     def calcula_matrices_de_recurrencia(self):
         self.matriz_recurrencia_region_cuadriculada = \
             m_recurr.calcula_matrices_de_recurrencia(self.arreglo_region_cuadriculada)
@@ -519,12 +537,12 @@ class Experimento:
 
     def obtener_indices_subsucesiones_iniciales_para_distancias(self, cantidad_indices_a_obtener):
         lista_de_indices_de_subsucesiones_iniciales = []
-        print("Obteniendo índices más altos...")
+        print("Obteniendo indices mas altos...")
         if self.lista_ordenada_de_indices_mas_altos is None:
-            print("Calculando nueva lista de índices más altos.")
+            print("Calculando nueva lista de indices mas altos.")
             self.lista_ordenada_de_indices_mas_altos = self.obtener_coeficientes_de_regiones_mas_visitadas(
                 cantidad_indices_a_obtener)
-        print("Lista ordenada de índices más altos: ", self.lista_ordenada_de_indices_mas_altos)
+        print("Lista ordenada de indices mas altos: ", self.lista_ordenada_de_indices_mas_altos)
         for indice in self.lista_ordenada_de_indices_mas_altos:
             for i in range(len(self.lista_con_subsucesiones)):
                 subsucesion = self.lista_con_subsucesiones[i]
@@ -697,7 +715,7 @@ class Experimento:
         data = pd.DataFrame(data)
         datos_a_exportar = data.append(pd.DataFrame(np.flipud(self.matriz_recurrencia_region_cuadriculada)))
         print(datos_a_exportar)
-        print('Aquí voy bien')
+        print('Aqui voy bien')
         data_para_matriz_tiempos = {'1': ['Time_in_Region_Matrix']}
         data_para_matriz_tiempos = pd.DataFrame(data_para_matriz_tiempos)
         data_para_matriz_tiempos = data_para_matriz_tiempos.append(pd.DataFrame(self.matriz_cuadriculada))
@@ -744,7 +762,7 @@ class Experimento:
 
     def graficar_figura(self, nombre_grafica, config_grafica):
         print("-----------------------------------------------------------")
-        print("Tipo de gráfica", nombre_grafica)
+        print("Tipo de grafica", nombre_grafica)
 
         limites_x, limites_y = config_grafica.regresa_config_grafica_general()
         lim_inf_x = limites_x[0]
@@ -809,6 +827,7 @@ class Experimento:
             print("Entro a distancias")
             lista_valores_minimos = []
             lista_valores_maximos = []
+
             if objeto_1_seleccionado is True:
                 print(1)
                 print(self.dist_objeto_1)
@@ -912,18 +931,24 @@ class Experimento:
             tiempo = np.linspace(0, longitud_serie_aceleracion_promediada, longitud_serie_aceleracion_promediada)
             plt.scatter(tiempo, aceleracion_promediada, s=1)
 
+        elif nombre_grafica == 'acel_hist':
+
+            print("Entro a acel_hist")
+            print(plt.hist(self.serie_aceleracion))
+            plt.hist(self.serie_aceleracion)
+
         # elif grafica == 'distPeso':
         #    print("Entro a distPeso")
         #    plt.plot(self.t, self.distPeso, color='black')
 
-        # Usa la distancia mínima a las palancas y grafica 1 si estuvo más próxima a la palanca 1,
-        # 2 si estuvo más próxima a la palanca 2 y 3 si estuvo más próxima a la palanca 3.
+        # Usa la distancia minima a las palancas y grafica 1 si estuvo mas proxima a la palanca 1,
+        # 2 si estuvo mas proxima a la palanca 2 y 3 si estuvo mas proxima a la palanca 3.
 
         # elif grafica == 'clasePalanca':
         #    plt.set_ylim(0.8, 3.2)
         #    plt.scatter(self.t.values, self.claseMinPalanca.values, s=5, c='black')
 
-        # Similar a la gráfica 'clasePalanca', pero agregando la distancia mínima al comedero y usando 0 para
+        # Similar a la grafica 'clasePalanca', pero agregando la distancia minima al comedero y usando 0 para
         # graficarla.
 
         # elif grafica == 'claseTodoPalanca':
@@ -938,16 +963,16 @@ class Experimento:
         #        r_1 = r_2
         #        r_2 = ((self.regionesFrecAc['Frecuencia'].iloc[i]) / suma_total) + r_1
         #        plt.plot(np.array([r_1, r_2]),
-        #                 np.array([self.regionesFrecAc['Región'].iloc[i], self.regionesFrecAc['Región'].iloc[i]]),
+        #                 np.array([self.regionesFrecAc['Region'].iloc[i], self.regionesFrecAc['Region'].iloc[i]]),
         #                 color='blue')
         #    plt.set_ylim(-1.2, 3.2)
 
-        # elif grafica == 'aceleraciónRegiones':
+        # elif grafica == 'aceleracionRegiones':
         #    plt.plot(np.arange(1, (len(self.regionesFrecAc)), 1), self.acelRegiones)
 
         # elif grafica == 'cambioRegiones/Acel':
         #    plt.set_ylim(-0.2, 3.2)
-        #    plt.scatter(np.arange(0, len(self.regionesFrecAc['Región'])), self.regionesFrecAc['Región'], s=5, c='black')
+        #    plt.scatter(np.arange(0, len(self.regionesFrecAc['Region'])), self.regionesFrecAc['Region'], s=5, c='black')
         #    plt.plot(np.arange(1, (len(self.regionesFrecAc)), 1), coeficiente * self.acelRegiones, '-', color='red')
 
         # elif grafica == 'matriz_recurrencia':
@@ -957,8 +982,8 @@ class Experimento:
 
         elif nombre_grafica == 'matriz_recurrencia_cuadriculada':
             plt.grid(False)
-            self.calcula_matrices_de_recurrencia()
-            print("Matriz de recurrencia región cuadriculada:", self.matriz_recurrencia_region_cuadriculada)
+
+            print("Matriz de recurrencia region cuadriculada:", self.matriz_recurrencia_region_cuadriculada)
             plt.imshow(-1 * self.matriz_recurrencia_region_cuadriculada, origin='lower', cmap='gray',
                        interpolation='nearest', vmin=-1, vmax=0)
 
@@ -996,7 +1021,8 @@ class Experimento:
 
         elif nombre_grafica == 'matriz_recurrencia_cuadriculada_combinada':
             plt.grid(False)
-            nueva_matriz_recurrencia_combinada = self.matriz_recurrencia_combinada + self.matriz_recurrencia_region_cuadriculada
+            nueva_matriz_recurrencia_combinada = self.matriz_recurrencia_combinada + \
+                                                 self.matriz_recurrencia_region_cuadriculada
             cmap = colors.ListedColormap(['white', 'black', 'blue', 'red', 'green', 'orange'])
             bounds = [0, 1, 2, 3, 4, 5]
             norm = colors.BoundaryNorm(bounds, cmap.N)
@@ -1019,7 +1045,7 @@ class Experimento:
 
         elif nombre_grafica == 'regresion_lineal':
 
-            print("Entro a regresión lineal")
+            print("Entro a regresion lineal")
 
             nombre_regresion_lineal = config_grafica.regresa_config_grafica_regresion_lineal()
             print("Nombre_regresion_lineal:", nombre_regresion_lineal)
@@ -1043,9 +1069,14 @@ class Experimento:
         elif nombre_grafica == 'cilindros_objetos_importantes':
             print("Entro a volumenes_objetos_importantes")
 
-            tamanio_volumenes, div_volumenes, tipo_grafica_volumen, rot_grafica_3d = \
+            objetos_seleccionados, tamanio_volumenes, div_volumenes, tipo_grafica_volumen, rot_grafica_3d = \
                 config_grafica.regresa_config_grafica_figuras()
 
+            objeto_1_seleccionado = objetos_seleccionados[0]
+            objeto_2_seleccionado = objetos_seleccionados[1]
+            objeto_3_seleccionado = objetos_seleccionados[2]
+            objeto_4_seleccionado = objetos_seleccionados[3]
+
             print("Tamaño_volumenes:", tamanio_volumenes)
             print("Div_volumenes:", div_volumenes)
             print("tipo_grafica_volumen:", tipo_grafica_volumen)
@@ -1060,37 +1091,42 @@ class Experimento:
                                                                              divisiones=div_volumenes,
                                                                              tipo=tipo_grafica_volumen)
 
+            print("Salgo de la funcion")
+
             if getattr(sys, 'frozen', False):
                 os.environ['BASEMAPDATA'] = os.path.join(os.path.dirname(sys.executable), 'mplot3d')
 
             ax = fig.add_subplot(111, projection='3d')
             ax.view_init(azim=rot_grafica_3d % 360, elev=0)
 
+            print("Cantidad de posiciones para volumenes:", self.cantidad_posiciones_volumenes)
+
             for i in range(0, len(self.cantidad_posiciones_volumenes[0])):
                 if objeto_1_seleccionado is True:
-                    fa.pintar_cilindro(self.objeto_relevante_1[0],
-                                       self.objeto_relevante_1[1],
-                                       self.radios_volumenes[i],
-                                       self.cantidad_posiciones_volumenes[0][i],
-                                       ax)
+                    m_ci.pintar_cilindro(self.objeto_relevante_1[0],
+                                         self.objeto_relevante_1[1],
+                                         self.radios_volumenes[i],
+                                         self.cantidad_posiciones_volumenes[0][i],
+                                         ax)
                 if objeto_2_seleccionado is True:
-                    fa.pintar_cilindro(self.objeto_relevante_2[0],
-                                       self.objeto_relevante_2[1],
-                                       self.radios_volumenes[i],
-                                       self.cantidad_posiciones_volumenes[1][i],
-                                       ax)
+                    m_ci.pintar_cilindro(self.objeto_relevante_2[0],
+                                         self.objeto_relevante_2[1],
+                                         self.radios_volumenes[i],
+                                         self.cantidad_posiciones_volumenes[1][i],
+                                         ax)
                 if objeto_3_seleccionado is True:
-                    fa.pintar_cilindro(self.objeto_relevante_3[0],
-                                       self.objeto_relevante_3[1],
-                                       self.radios_volumenes[i],
-                                       self.cantidad_posiciones_volumenes[2][i],
-                                       ax)
+                    m_ci.pintar_cilindro(self.objeto_relevante_3[0],
+                                         self.objeto_relevante_3[1],
+                                         self.radios_volumenes[i],
+                                         self.cantidad_posiciones_volumenes[2][i],
+                                         ax)
                 if objeto_4_seleccionado is True:
-                    fa.pintar_cilindro(self.objeto_relevante_4[0],
-                                       self.objeto_relevante_4[1],
-                                       self.radios_volumenes[i],
-                                       self.cantidad_posiciones_volumenes[3][i],
-                                       ax)
+                    m_ci.pintar_cilindro(self.objeto_relevante_4[0],
+                                         self.objeto_relevante_4[1],
+                                         self.radios_volumenes[i],
+                                         self.cantidad_posiciones_volumenes[3][i],
+                                         ax)
+
             ax.set_xlim(0, 100)
             ax.set_ylim(0, 100)
             ax.set_zlim(0, len(self.posiciones_x))
