@@ -72,14 +72,31 @@ class MultiplesExperimentos:
         for experimento in self.lista_experimentos:
             experimento.calcula_velocidades()
 
-    def calcula_regiones_cuadriculadas(self, arreglo_regiones_preferidas):
+    def calcula_regiones_cuadriculadas(self,
+                                       arreglo_regiones_preferidas,
+                                       tamanio_vectores,
+                                       umbral,
+                                       sobreposicion):
         for experimento in self.lista_experimentos:
-            experimento.calcula_regiones_cuadriculadas()
+            experimento.calcula_regiones_cuadriculadas(tamanio_vectores,
+                                                       umbral,
+                                                       sobreposicion)
             experimento.calcula_matrices_solo_regiones_preferidas(regiones_preferidas=arreglo_regiones_preferidas)
 
-    def calcula_entropias_divergencias(self, tamanio_vectores=2, umbral=3):
+    def calcula_entropias_divergencias(self):
         for experimento in self.lista_experimentos:
-            experimento.calcula_entropias(tamanio_vectores, umbral)
+            experimento.calcula_entropias()
+
+    def calcula_entropias_aproximadas(self,
+                                      tamanio_vectores=2,
+                                      brinco_datos=1,
+                                      umbral=3,
+                                      sobreposicion=True):
+        for experimento in self.lista_experimentos:
+            experimento.calcula_entropias_aproximadas_vel_acel(tamanio_vectores=tamanio_vectores,
+                                                               umbral=umbral,
+                                                               brinco_datos=brinco_datos,
+                                                               sobreposicion=sobreposicion)
 
     def calcula_regresiones_lineales(self, brinco_temporal, longitud_ventana_tiempo):
         for experimento in self.lista_experimentos:
